@@ -1,15 +1,18 @@
 """
-    flaskext.slack
+    flask_slack
     ~~~~~~~~~~~~~~~
 
-    Slack exntension for Flask.
+    Slack extension for Flask.
 
     :copyright: (c) 2014 by VeryCB.
     :license: BSD, see LICENSE for more details.
 """
 
+from six import string_types
+
+
 __all__ = ('Slack',)
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 __author__ = 'VeryCB <imcaibin@gmail.com>'
 
 
@@ -51,13 +54,13 @@ class Slack(object):
         team_id = data.get('team_id')
         command = data.get('command')
 
-        if isinstance(command, basestring):
+        if isinstance(command, string_types):
             command = command.strip().lstrip('/')
 
         try:
             self.validate(command, token, team_id, method)
-        except RuntimeError as e:
-            return self.response(e.message)
+        except SlackError as e:
+            return self.response(e.msg)
 
         func, _, _, kwargs = self._commands[(team_id, command)]
         kwargs.update(data.to_dict())
@@ -68,17 +71,23 @@ class Slack(object):
 
     def validate(self, command, token, team_id, method):
         if (team_id, command) not in self._commands:
-            raise RuntimeError('Command {0} is not found in team {1}'.format(
-                               command, team_id))
+            raise SlackError('Command {0} is not found in team {1}'.format(
+                             command, team_id))
 
         func, _token, methods, kwargs = self._commands[(team_id, command)]
 
         if method not in methods:
-            raise RuntimeError('{} request is not allowed'.format(method))
+            raise SlackError('{} request is not allowed'.format(method))
 
         if token != _token:
-            raise RuntimeError('Your token {} is invalid'.format(token))
+            raise SlackError('Your token {} is invalid'.format(token))
 
     def response(self, text):
         from flask import Response
         return Response(text, content_type='text/plain; charset=utf-8')
+
+
+class SlackError(Exception):
+
+    def __init__(self, msg):
+        self.msg = msg
